"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.exceptNumber = exports.exceptNotBlank = exports.exceptBlank = exports.exceptNotEmpty = exports.exceptEmpty = exports.exceptFalse = exports.exceptTrue = exports.exceptNotNull = exports.exceptNull = exports.asException = exports.throwException = exports.throwApiException = void 0;
const lodash_1 = __importDefault(require("lodash"));
const FunctionUtils_1 = require("./FunctionUtils");
const ObjectUtils_1 = require("./ObjectUtils");
const throwException = (message, logError = FunctionUtils_1.doNothing) => {
    logError && logError(message);
    throw message;
};
exports.throwException = throwException;
const throwApiException = (message, opts, options) => {
    if ((0, ObjectUtils_1.suspectedNil)(message)) {
        console.log("throwApiException, but message is null ");
    }
    let m = (message === null || message === void 0 ? void 0 : message.message) || message;
    if (!lodash_1.default.isString(m) || (0, ObjectUtils_1.suspectedNil)(m)) {
        console.log("throwApiException, but message is object ", m);
        m = `错误: [${(0, ObjectUtils_1.exceptString)(m)}]`;
    }
    throw m;
};
exports.throwApiException = throwApiException;
const asException = (messageTemplate, opts = {}) => {
    if (lodash_1.default.isString(messageTemplate)) {
        throwException(messageTemplate
            ? lodash_1.default.template(messageTemplate)(opts)
            : "except some error~~~");
    }
    if (lodash_1.default.isFunction(messageTemplate)) {
        const message = messageTemplate(opts);
        throwException(message !== null && message !== void 0 ? message : "except some error~~~");
    }
};
exports.asException = asException;
const exceptTrue = (value, message, opts = {}) => {
    if (lodash_1.default.isNil(value) || value === false) {
        asException(message, opts);
    }
    if (lodash_1.default.isFunction(value)) {
        exceptTrue(value(), message, opts);
    }
    return value;
};
exports.exceptTrue = exceptTrue;
const exceptFalse = (value, message, opts = {}) => exceptTrue(!value, message, opts);
exports.exceptFalse = exceptFalse;
const exceptNull = (value, message, opts = {}) => exceptTrue(lodash_1.default.isNil(value), message, opts);
exports.exceptNull = exceptNull;
const exceptNotNull = (value, message, opts = {}) => exceptTrue(!lodash_1.default.isNil(value), message, opts);
exports.exceptNotNull = exceptNotNull;
const exceptEmpty = (value, message, opts = {}) => {
    if (lodash_1.default.isFunction(value)) {
        exceptEmpty(value(), message, opts);
    }
    else {
        exceptTrue(lodash_1.default.isEmpty(value), message, opts);
    }
};
exports.exceptEmpty = exceptEmpty;
const exceptNotEmpty = (value, message, opts = {}) => {
    if (lodash_1.default.isFunction(value)) {
        exceptNotEmpty(value(), message, opts);
    }
    else {
        exceptFalse(lodash_1.default.isEmpty(value), message, opts);
    }
};
exports.exceptNotEmpty = exceptNotEmpty;
const exceptBlank = (value, message, opts = {}) => {
    if (lodash_1.default.isString(value)) {
        exceptEmpty(lodash_1.default.trim(value), message, opts);
    }
    else {
        exceptEmpty(value, message, opts);
    }
};
exports.exceptBlank = exceptBlank;
const exceptNotBlank = (value, message, opts = {}) => {
    if (lodash_1.default.isString(value)) {
        exceptNotEmpty(lodash_1.default.trim(value), message, opts);
    }
    else {
        exceptEmpty(value, message, opts);
    }
};
exports.exceptNotBlank = exceptNotBlank;
const exceptNumber = (value, message = null) => {
    if (!lodash_1.default.isFinite(value)) {
        throwException(message || `value:[${value}] must be number`);
    }
};
exports.exceptNumber = exceptNumber;
//# sourceMappingURL=ExceptionUtils.js.map