"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.string2Array = exports.notBlank = exports.isBlank = exports.suspectedNil = exports.exceptBoolean = exports.exceptObject = exports.exceptString = exports.exceptArray = exports.transToString = exports.acceptFromString = void 0;
const lodash_1 = __importDefault(require("lodash"));
const moment_1 = __importDefault(require("moment"));
const DateUtils_1 = require("./DateUtils");
const FunctionUtils_1 = require("./FunctionUtils");
const StringUtils_1 = require("./StringUtils");
/**
 * null, undefined, NaN  为空 ==> true
 * 字符串中 'null'(ignore case), 'undefined' (ignore case), '', 'NaN'  即为空 ==> true
 * [] {} 即为空  ==> true
 * boolean false 为空  ==> true
 * ----------------------------------------------------------------------
 * 其他为 非空 ==> false
 * 数字0  非空 ==> false
 * boolean true 非空 ==> false
 * @param value 输入
 */
const suspectedNil = (value) => {
    let v = value;
    if (lodash_1.default.isNil(v) || lodash_1.default.isNaN(v)) {
        return true;
    }
    if (v === FunctionUtils_1.doNothing || v === FunctionUtils_1.voidFunction) {
        return true;
    }
    if (typeof v === "number") {
        // _.isNumber(v)
        return false;
    }
    if (typeof v === "boolean") {
        return !v;
    }
    if (lodash_1.default.isEmpty(v)) {
        return true;
    }
    if (typeof v !== "string") {
        // _.isString(v)
        return false;
    }
    if ("NaN" === v) {
        return true;
    }
    v = lodash_1.default.toLower(lodash_1.default.trim(v));
    return "undefined" === v || "null" === v || "" === v;
};
exports.suspectedNil = suspectedNil;
const isBlank = (v) => suspectedNil(v);
exports.isBlank = isBlank;
const notBlank = (v) => !isBlank(v);
exports.notBlank = notBlank;
const string2Array = (str, opts = {}) => {
    const { defaultValue = [], separator = "," } = opts;
    let result = defaultValue;
    if (!suspectedNil(str) && lodash_1.default.isString(str)) {
        if ((0, StringUtils_1.isJsonString)(str)) {
            const r = JSON.parse(str);
            result = lodash_1.default.isArray(r) ? r : [r];
        }
        else {
            result = lodash_1.default.split(str, separator);
        }
    }
    return result;
};
exports.string2Array = string2Array;
const exceptArray = (v, opts = {}) => {
    var _a;
    const { defaultValue = [], transToArrayFn = string2Array, ignoreFunction = true, onlyPrimitive = false, } = opts;
    let result = defaultValue;
    let input = v;
    if (lodash_1.default.isFunction(input)) {
        if (ignoreFunction) {
            input = defaultValue;
        }
        else {
            input = (_a = v(opts)) !== null && _a !== void 0 ? _a : defaultValue;
        }
    }
    if (lodash_1.default.isArray(input)) {
        result = input;
    }
    else if (lodash_1.default.isString(input)) {
        result = transToArrayFn(input, opts);
    }
    else if (lodash_1.default.isNumber(input)) {
        result = [input];
    }
    else if (lodash_1.default.isObject(input)) {
        result = [input];
    }
    return result;
};
exports.exceptArray = exceptArray;
const exceptString = (v, opts) => {
    var _a;
    const { defaultValue = "", separator = ",", transToStringFn = (v) => JSON.stringify(v, null, 2), ignoreFunction = true, onlyPrimitive = false, } = opts !== null && opts !== void 0 ? opts : {};
    let result = defaultValue;
    let input = v;
    if (lodash_1.default.isFunction(input)) {
        if (ignoreFunction) {
            input = defaultValue;
        }
        else {
            input = (_a = v(opts)) !== null && _a !== void 0 ? _a : defaultValue;
        }
    }
    if (lodash_1.default.isArray(input)) {
        result = lodash_1.default.join(input, separator);
    }
    else if (lodash_1.default.isString(input)) {
        result = input;
    }
    else if (lodash_1.default.isNumber(input)) {
        result = input + "";
    }
    else if (lodash_1.default.isDate(input)) {
        result = (0, DateUtils_1.formatDateTime)(input);
    }
    else if (moment_1.default.isMoment(input)) {
        result = (0, DateUtils_1.formatDateTime)(input);
    }
    else if (lodash_1.default.isBoolean(input)) {
        result = input + "";
    }
    else if (lodash_1.default.isObject(input)) {
        result = transToStringFn(input, opts);
    }
    return result;
};
exports.exceptString = exceptString;
const acceptFromString = (str, accept = "string") => {
    let r = str;
    if (suspectedNil(r)) {
        return null;
    }
    switch (accept) {
        case "string": {
            break;
        }
        case "array": {
            if (lodash_1.default.startsWith(r.trim(), "[")) {
                console.debug(` acceptFromString r:  `, r);
                r = JSON.parse(r);
            }
            else {
                r = lodash_1.default.chain(r).split(",").map(lodash_1.default.trim).value();
            }
            break;
        }
        case "object": {
            r = JSON.parse(r);
            break;
        }
        case "boolean": {
            r = lodash_1.default.toLower(r) === "true";
            break;
        }
        case "int":
        case "integer":
        case "float":
        case "double":
        case "number": {
            r = lodash_1.default.toNumber(r);
            break;
        }
        case "datetime":
        case "date": {
            r = (0, moment_1.default)(r);
            break;
        }
        default:
            throw `wrong type with accept:[${accept}]`;
    }
    return r;
};
exports.acceptFromString = acceptFromString;
const transToString = (target, defaultValue = null, opts = {}) => {
    if (lodash_1.default.isNil(target)) {
        return defaultValue;
    }
    const { onlyPrimitive = true } = opts;
    if (lodash_1.default.isDate(target)) {
        return (0, DateUtils_1.formatDateTime)(target);
    }
    else if (lodash_1.default.isFunction(target)) {
        return undefined;
    }
    else if (lodash_1.default.isObject(target)) {
        if (onlyPrimitive) {
            return undefined;
        }
        else {
            return JSON.stringify(target, null, 2);
        }
    }
    else {
        return lodash_1.default.toString(target);
    }
};
exports.transToString = transToString;
const exceptObject = (v, opts = {}) => {
    var _a;
    const { defaultValue = {}, transToObjectFn = (v) => JSON.parse(v), ignoreFunction = true, onlyPrimitive = false, } = opts;
    let result = defaultValue;
    let input = v;
    if (lodash_1.default.isFunction(input)) {
        if (ignoreFunction) {
            input = defaultValue;
        }
        else {
            input = (_a = v(opts)) !== null && _a !== void 0 ? _a : defaultValue;
        }
    }
    if (lodash_1.default.isString(input)) {
        result = transToObjectFn(input, opts);
    }
    else if (lodash_1.default.isObject(input)) {
        result = input;
    }
    return result;
};
exports.exceptObject = exceptObject;
const exceptBoolean = (target) => {
    let v = target;
    if (lodash_1.default.isFunction(v)) {
        v = target();
    }
    if (suspectedNil(v)) {
        return false;
    }
    return !(lodash_1.default.isString(v) && lodash_1.default.toLower(v) === "false");
};
exports.exceptBoolean = exceptBoolean;
//# sourceMappingURL=ObjectUtils.js.map