"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.startsWithIgnoreCase = exports.isJsonString = exports.chunk = exports.equalIgnoreCase = void 0;
const lodash_1 = __importDefault(require("lodash"));
const ObjectUtils_1 = require("./ObjectUtils");
/**
 * 判断是否能转为json
 * @param str 输入
 */
const isJsonString = (str) => {
    if ((0, ObjectUtils_1.suspectedNil)(str)) {
        return false;
    }
    if (!lodash_1.default.isString(str)) {
        return false;
    }
    try {
        return lodash_1.default.isObject(JSON.parse(str));
    }
    catch (e) {
        return false;
    }
};
exports.isJsonString = isJsonString;
/**
 * 比较字符串是否相同, 忽略大小写
 * @param {string} v1 输入1
 * @param {string} v2 输入2
 * @return {boolean}  相同为true
 */
const equalIgnoreCase = (v1, v2) => {
    if ((0, ObjectUtils_1.suspectedNil)(v1) || (0, ObjectUtils_1.suspectedNil)(v2)) {
        return v1 === v2;
    }
    else {
        return lodash_1.default.toLower(v1) === lodash_1.default.toLower(v2);
    }
};
exports.equalIgnoreCase = equalIgnoreCase;
/**
 * 比较字符串是否开始, 忽略大小写
 * @param {string} v1 目标字符串
 * @param {string} v2 比较字符串
 * @return {boolean}  V1 以 V2开始 为true
 */
const startsWithIgnoreCase = (v1, v2) => {
    if ((0, ObjectUtils_1.suspectedNil)(v1) || (0, ObjectUtils_1.suspectedNil)(v2)) {
        return lodash_1.default.startsWith(v1, v2);
    }
    return lodash_1.default.startsWith(lodash_1.default.toLower(v1), lodash_1.default.toLower(v2));
};
exports.startsWithIgnoreCase = startsWithIgnoreCase;
/**
 * 输入字符串str , 按size截断为数组, 当str长度小于initSize时不切; 当str为空时不切
 * @param str 输入
 * @param opts 选项
 * @param {number} opts.size     截断大小
 * @param {number} opts.initSize 忽略大小
 * @return
 */
const chunk = (str = null, opts = {}) => {
    const { size = 10, initSize = 12 } = opts;
    if (lodash_1.default.isNil(str) || !lodash_1.default.isString(str)) {
        return str;
    }
    if (str.length <= initSize) {
        return [str];
    }
    return lodash_1.default.chain(str)
        .split("")
        .chunk(size)
        .map((s) => lodash_1.default.join(s, ""))
        .value();
};
exports.chunk = chunk;
//# sourceMappingURL=StringUtils.js.map