"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findNode = exports.eachTree = exports.mapTree = exports.filterMultiTreeNode = exports.filterTreeNode = exports.formatChildren = exports.appendLevel = void 0;
/* istanbul ignore file */
const lodash_1 = __importDefault(require("lodash"));
const DEFAULT_ID_KEY = "organizationCode";
const DEFAULT_PARENT_KEY = "parentOrganizationCode";
const DEFAULT_CHIILDREN_KEY = "children";
const DEFAULT_LEVEL_KEY = "level";
const DEFAULT_LEVEL_FOR_NO_LEVEL = -1;
const appendLevel = ({ list = [], levelKey = DEFAULT_LEVEL_KEY, level = 0 }) => lodash_1.default.map(list, (p) => (Object.assign(Object.assign({}, p), { [levelKey]: level })));
exports.appendLevel = appendLevel;
const formatChildren = ({ list, parent, idKey = DEFAULT_ID_KEY, parentKey = DEFAULT_PARENT_KEY, level = DEFAULT_LEVEL_FOR_NO_LEVEL, levelKey = DEFAULT_LEVEL_KEY, childrenKey = DEFAULT_CHIILDREN_KEY, }) => {
    if (!parent[idKey]) {
        console.warn(`parent has not id:[${idKey}]..., parent:${JSON.stringify(parent)}`);
        return list;
    }
    const children = lodash_1.default.filter(list, (l) => l[parentKey] === parent[idKey]);
    lodash_1.default.each(children, (parent) => formatChildren({
        list,
        idKey,
        parentKey,
        parent,
        level: ~level ? level + 1 : -1,
        levelKey,
        childrenKey,
    }));
    if (!lodash_1.default.isEmpty(children)) {
        parent[childrenKey] = ~level
            ? appendLevel({ list: children, level, levelKey })
            : children;
    }
    return parent;
};
exports.formatChildren = formatChildren;
const filterTreeNode = ({ tree, fn, childKey = "children" }) => {
    const { [childKey]: children } = tree;
    return children
        ? Object.assign(Object.assign({}, tree), { [childKey]: filterMultiTreeNode({ children, fn, childKey }) }) : tree;
};
exports.filterTreeNode = filterTreeNode;
const filterMultiTreeNode = ({ children, fn, childKey = "children" }) => {
    if (lodash_1.default.isEmpty(children)) {
        return [];
    }
    return lodash_1.default.chain(children)
        .map((c) => (fn(c) ? filterTreeNode({ tree: c, fn, childKey }) : null))
        .compact()
        .value();
};
exports.filterMultiTreeNode = filterMultiTreeNode;
const mapTree = ({ tree, fn, forward = true, childKey = "children" }) => {
    if (!tree) {
        return tree;
    }
    if (lodash_1.default.isArray(tree)) {
        return lodash_1.default.map(tree, (t) => mapTree({ tree: t, fn, childKey }));
    }
    else if (lodash_1.default.isObject(tree)) {
        let self = {};
        forward && (self = fn(tree));
        const children = mapTree({
            // @ts-ignore
            tree: forward ? self[childKey] : tree[childKey],
            fn,
            forward,
            childKey,
        });
        !forward && (self = fn(tree));
        if (lodash_1.default.isEmpty(children)) {
            return Object.assign({}, self);
        }
        else {
            return Object.assign(Object.assign({}, self), { [childKey]: children });
        }
    }
    else {
        // console.log(` eachTree tree WTF ?? `, tree);
        return tree;
    }
};
exports.mapTree = mapTree;
const eachTree = ({ tree, fn, forward = true, walkNext = true }) => {
    if (!tree) {
        return true;
    }
    if (lodash_1.default.isArray(tree)) {
        lodash_1.default.each(tree, (t) => eachTree({ tree: t, fn, walkNext }));
    }
    else if (lodash_1.default.isObject(tree)) {
        if (walkNext) {
            let doNext = walkNext;
            forward && (doNext = fn(tree));
            if (doNext) {
                // @ts-ignore
                doNext = eachTree({
                    // @ts-ignore
                    tree: tree.children,
                    fn,
                    forward,
                    walkNext: doNext,
                });
            }
            !forward && (doNext = fn(tree));
            return doNext;
        }
        else {
            return walkNext;
        }
    }
    else {
        return false;
    }
};
exports.eachTree = eachTree;
const findNode = ({ tree, idKey, filter }) => {
    let result = null;
    eachTree({
        tree,
        fn: (node) => {
            if (node[idKey] === filter) {
                result = node;
                return false;
            }
            else {
                return true;
            }
        },
    });
    return result;
};
exports.findNode = findNode;
//# sourceMappingURL=TreeUtils.js.map