"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.expandUrl = exports.isAbsolutePath = exports.decodeParam = exports.encodeParam = exports.pathJoin = void 0;
const lodash_1 = __importDefault(require("lodash"));
const Base64Utils_1 = require("./Base64Utils");
const ObjectUtils_1 = require("./ObjectUtils");
const StringUtils_1 = require("./StringUtils");
const HEADER = ["http", "https", "ws"];
const NECK = "://";
const SEPARATOR = "/";
const REG_SEPARATOR = new RegExp(`${SEPARATOR}{1,}`, "g");
/**
 * 链接 URL 片段
 * @param all 所有参数
 */
const pathJoin = (...all) => {
    var _a;
    const arr = lodash_1.default.compact(all);
    if (lodash_1.default.isEmpty(arr)) {
        return "";
    }
    let [first, ...tail] = arr;
    let header = (_a = lodash_1.default.find(HEADER, (h) => (0, StringUtils_1.startsWithIgnoreCase)(first, `${lodash_1.default.toLower(h)}${NECK}`))) !== null && _a !== void 0 ? _a : "";
    if (header) {
        first = first.substring(header.length + NECK.length);
        header = header + NECK;
    }
    const r = lodash_1.default.chain([first, ...tail])
        .filter((a) => !lodash_1.default.isNil(a))
        .map(ObjectUtils_1.exceptString)
        .join(SEPARATOR)
        .value()
        .replace(REG_SEPARATOR, SEPARATOR);
    return header + r;
};
exports.pathJoin = pathJoin;
/**
 * 参数编码遮罩编码, 默认base64
 * @param value 遮罩目标
 * @param {Object} opts 配置项
 * @param {Function} opts.maskFn 遮罩函数 默认按Base64
 */
const encodeParam = (value, opts = { encodeFn: Base64Utils_1.encodeBase64 }) => {
    const { encodeFn } = opts;
    return encodeFn(value);
};
exports.encodeParam = encodeParam;
/**
 * 参数编码遮罩解码, 默认base64
 * @param value 解码目标
 * @param {Object} opts 配置项
 * @param {Function} opts.maskFn 解码函数 默认按Base64
 */
const decodeParam = (value, opts = { decodeFn: Base64Utils_1.decodeBase64 }) => {
    const { decodeFn } = opts;
    return decodeFn(value);
};
exports.decodeParam = decodeParam;
const _checkAbsolutePathFn = (str) => (protocol) => (0, StringUtils_1.startsWithIgnoreCase)(str, `${protocol}://`);
/**
 * 检测是否是绝对路径
 * @param str             输入
 * @param opts            可项
 * @param opts.protocol   检测协议, 默认为 ["http", "https", "ws"]
 * @return isAbsolute
 */
const isAbsolutePath = (str, opts = { protocol: HEADER }) => {
    if (lodash_1.default.isNil(str)) {
        return false;
    }
    const { protocol } = opts;
    const p = lodash_1.default.flatten([protocol]);
    const fn = _checkAbsolutePathFn(str);
    return lodash_1.default.some(p, fn);
};
exports.isAbsolutePath = isAbsolutePath;
const expandUrl = (url, params = [], opts = {}) => {
    if (lodash_1.default.isNil(url)) {
        return url;
    }
    const p = lodash_1.default.assign({}, ...lodash_1.default.flatten([params]));
    const symbol = lodash_1.default.includes(url, "?") ? "&" : "?";
    const s = lodash_1.default.chain(p)
        .map((v, k) => {
        const vv = (0, ObjectUtils_1.transToString)(v);
        return lodash_1.default.isNil(vv) ? null : `${k}=${vv}`;
    })
        .compact()
        .value()
        .join("&");
    return `${url}${symbol}${s}`;
};
exports.expandUrl = expandUrl;
//# sourceMappingURL=UrlUtils.js.map